/*
 * console.c
 *
 * Version: 1.0
 * Created: 2018-07-15
 *  Author: Wolfgang Neff
 */ 

#include <stdlib.h>
#include <avr/io.h>

#include "board.h"
#include "console.h"

static FILE console_in = FDEV_SETUP_STREAM(NULL, NULL, _FDEV_SETUP_READ);
static FILE console_out = FDEV_SETUP_STREAM(NULL, NULL, _FDEV_SETUP_WRITE);

static int usart_getc(FILE *stream)
{
	while (!(VCOM_MODULE.STATUS & USART_RXCIF_bm));
	char data = VCOM_MODULE.RXDATAL;
	return (data=='\r') ? '\n' : data;
}

static int usart_putc(char c, FILE *stream)
{
	if (c == '\n') usart_putc('\r', stream);
	while (!(VCOM_MODULE.STATUS & USART_DREIF_bm));
	VCOM_MODULE.TXDATAL = c;
	return EXIT_SUCCESS;
}

void console_init(void)
{
	VCOM_PORT.OUT |= VCOM_TX_PIN_bm;
	VCOM_PORT.DIR |= VCOM_TX_PIN_bm;
	VCOM_PORT.DIR &= ~VCOM_RX_PIN_bm;
	VCOM_MODULE.BAUD = VCOM_BAUDRATE;
	VCOM_MODULE.CTRLC = VCOM_CONFIG;
	VCOM_MODULE.CTRLB |= (USART_RXEN_bm | USART_TXEN_bm);
	console_in.get = usart_getc;
	console_out.put = usart_putc;
   	stdin  = &console_in;
    stderr = &console_out;
    stdout = &console_out;
}

void console_clear(void)
{
	putchar('\x1B');
	putchar('[');
	putchar('2');
	putchar('J');
	putchar('\x1B');
	putchar('[');
	putchar('H');
}
